@@ -139,7 +139,9 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     }
 
     actionCollection()->addAssociatedWidget(view);
-    foreach(QAction * action, actionCollection()->actions()) {
+
+    const QList<QAction *> actionsList = actionCollection()->actions();
+    for (QAction *action : actionsList) {
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     }
 
@@ -211,6 +213,9 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     connect(backgroundTimer, &QTimer::timeout, this, &Konsole::SessionController::snapshot);
     backgroundTimer->start();
 
+    // xterm '10;?' request
+    connect(_session.data(), &Konsole::Session::getForegroundColor,
+            this, &Konsole::SessionController::sendForegroundColor);
     // xterm '11;?' request
     connect(_session.data(), &Konsole::Session::getBackgroundColor,
             this, &Konsole::SessionController::sendBackgroundColor);
@@ -232,6 +237,9 @@ SessionController::~SessionController()
     if (!_editProfileDialog.isNull()) {
         delete _editProfileDialog.data();
     }
+    if(factory()) {
+        factory()->removeClient(this);
+    }
 }
 void SessionController::trackOutput(QKeyEvent* event)
 {
@@ -428,7 +436,7 @@ void SessionController::updateWebSearchMenu()
 
             QAction* action = nullptr;
 
-            foreach(const QString& searchProvider, searchProviders) {
+            for (const QString &searchProvider : searchProviders) {
                 action = new QAction(searchProvider, _webSearchMenu);
                 action->setIcon(QIcon::fromTheme(filterData.iconNameForPreferredSearchProvider(searchProvider)));
                 action->setData(filterData.queryForPreferredSearchProvider(searchProvider));
@@ -474,6 +482,12 @@ void SessionController::sendSignal(QAction* action)
     _session->sendSignal(signal);
 }
 
+void SessionController::sendForegroundColor()
+{
+    const QColor c = _view->getForegroundColor();
+    _session->reportForegroundColor(c);
+}
+
 void SessionController::sendBackgroundColor()
 {
     const QColor c = _view->getBackgroundColor();
@@ -825,12 +839,12 @@ EditProfileDialog* SessionController::profileDialogPointer()
 void SessionController::editCurrentProfile()
 {
     // Searching for Edit profile dialog opened with the same profile
-    const QList<SessionController*> allSessionsControllers = _allControllers.values();
-    foreach (SessionController* session, allSessionsControllers) {
-        if ((session->profileDialogPointer() != nullptr)
-                && session->profileDialogPointer()->isVisible()
-                && session->profileDialogPointer()->lookupProfile() == SessionManager::instance()->sessionProfile(_session)) {
-            session->profileDialogPointer()->close();
+    for (SessionController *controller : qAsConst(_allControllers)) {
+        if ( (controller->profileDialogPointer() != nullptr)
+             && controller->profileDialogPointer()->isVisible()
+             && (controller->profileDialogPointer()->lookupProfile()
+                 == SessionManager::instance()->sessionProfile(_session)) ) {
+            controller->profileDialogPointer()->close();
         }
     }
 
@@ -1016,7 +1030,8 @@ static const KXmlGuiWindow* findWindow(const QObject* object)
 static bool hasTerminalDisplayInSameWindow(const Session* session, const KXmlGuiWindow* window)
 {
     // Iterate all TerminalDisplays of this Session ...
-    foreach(const TerminalDisplay* terminalDisplay, session->views()) {
+    const QList<TerminalDisplay *> views = session->views();
+    for (const TerminalDisplay *terminalDisplay : views) {
         // ... and check whether a TerminalDisplay has the same
         // window as given in the parameter
         if (window == findWindow(terminalDisplay)) {
@@ -1099,8 +1114,8 @@ void SessionController::copyInputToSelectedTabs()
         QSet<Session*> newGroup = dialog->chosenSessions();
         newGroup.remove(_session);
 
-        QSet<Session*> completeGroup = newGroup | currentGroup;
-        foreach(Session * session, completeGroup) {
+        const QSet<Session *> completeGroup = newGroup | currentGroup;
+        for (Session *session : completeGroup) {
             if (newGroup.contains(session) && !currentGroup.contains(session)) {
                 _copyToGroup->addSession(session);
             } else if (!newGroup.contains(session) && currentGroup.contains(session)) {
@@ -1552,7 +1567,7 @@ void SessionController::updateSessionIcon()
 {
     // If the default profile icon is being used, don't put it on the tab
     // Only show the icon if the user specifically chose one
-    if (_session->iconName() == QLatin1String("utilities-terminal")) {
+    if (_session->iconName() == QStringLiteral("utilities-terminal")) {
         _sessionIconName = QString();
     } else {
         _sessionIconName = _session->iconName();
@@ -1643,9 +1658,10 @@ void SessionController::sessionReadOnlyChanged() {
     updateReadOnlyActionStates();
 
     // Update all views
-    foreach (TerminalDisplay* view, session()->views()) {
-        if (view != _view.data()) {
-            view->updateReadOnlyState(isReadOnly());
+    const QList<TerminalDisplay *> viewsList = session()->views();
+    for (TerminalDisplay *terminalDisplay : viewsList) {
+        if (terminalDisplay != _view.data()) {
+            terminalDisplay->updateReadOnlyState(isReadOnly());
         }
     }
 }
@@ -1668,12 +1684,15 @@ void SessionController::showDisplayContextMenu(const QPoint& position)
     if (!popup.isNull()) {
         updateReadOnlyActionStates();
 
-        // prepend content-specific actions such as "Open Link", "Copy Email Address" etc.
-        QList<QAction*> contentActions = _view->filterActions(position);
         auto contentSeparator = new QAction(popup);
         contentSeparator->setSeparator(true);
-        contentActions << contentSeparator;
-        popup->insertActions(popup->actions().value(0, nullptr), contentActions);
+
+        // prepend content-specific actions such as "Open Link", "Copy Email Address" etc.
+        QSharedPointer<Filter::HotSpot> hotSpot = _view->filterActions(position);
+        if (hotSpot) {
+            popup->insertActions(popup->actions().value(0, nullptr), hotSpot->actions() << contentSeparator );
+
+        }
 
         // always update this submenu before showing the context menu,
         // because the available search services might have changed
@@ -1690,7 +1709,9 @@ void SessionController::showDisplayContextMenu(const QPoint& position)
             }
         }
 
-        QAction* chosen = popup->exec(_view->mapToGlobal(position));
+        // they are here.
+        // qDebug() << popup->actions().indexOf(contentActions[0]) << popup->actions().indexOf(contentActions[1]) << popup->actions()[3];
+        QAction* chosen = popup->exec(QCursor::pos());
 
         // check for validity of the pointer to the popup menu
         if (!popup.isNull()) {
